rayoptics.util package
======================

.. automodule:: rayoptics.util
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

rayoptics.util.colors module
----------------------------

.. automodule:: rayoptics.util.colors
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.util.colour\_system module
------------------------------------

.. automodule:: rayoptics.util.colour_system
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.util.dict2d module
----------------------------

.. automodule:: rayoptics.util.dict2d
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.util.line\_intersection module
----------------------------------------

.. automodule:: rayoptics.util.line_intersection
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.util.misc\_math module
--------------------------------

.. automodule:: rayoptics.util.misc_math
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.util.rgb2mpl module
-----------------------------

.. automodule:: rayoptics.util.rgb2mpl
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.util.rgbtable module
------------------------------

.. automodule:: rayoptics.util.rgbtable
   :members:
   :undoc-members:
   :show-inheritance:

rayoptics.util.spectral\_lines module
-------------------------------------

.. automodule:: rayoptics.util.spectral_lines
   :members:
   :undoc-members:
   :show-inheritance:

